@@ -90,6 +90,144 @@ class AsrTimestamps(AbstractModel):
         
 
 
+class CheckAnimateImageJobRequest(AbstractModel):
+    """CheckAnimateImageJob请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _TemplateId: 动作模板ID。
+        :type TemplateId: str
+        :param _ImageUrl: 图片格式：支持PNG、JPG、JPEG、BMP、WEBP格式；
+图片分辨率：长边分辨率范围【192，4096】；
+图片大小：不超过10M；
+图片宽高比：【宽：高】数值在 1:2 到 1:1.2 范围内
+        :type ImageUrl: str
+        :param _ImageBase64: 图片base64数据。
+图片格式：支持PNG、JPG、JPEG、BMP、WEBP格式；
+图片分辨率：长边分辨率范围【192，4096】；
+图片大小：不超过10M；
+图片宽高比：【宽：高】数值在 1:2 到 1:1.2 范围内
+        :type ImageBase64: str
+        :param _EnableBodyJoins: 是否检测输入图人体12个身体部位（头部、颈部、右肩、右肘、右腕、左肩、左肘、左腕、右髋、左髋,、左膝、右膝）。默认不检测。
+        :type EnableBodyJoins: bool
+        """
+        self._TemplateId = None
+        self._ImageUrl = None
+        self._ImageBase64 = None
+        self._EnableBodyJoins = None
+
+    @property
+    def TemplateId(self):
+        """动作模板ID。
+        :rtype: str
+        """
+        return self._TemplateId
+
+    @TemplateId.setter
+    def TemplateId(self, TemplateId):
+        self._TemplateId = TemplateId
+
+    @property
+    def ImageUrl(self):
+        """图片格式：支持PNG、JPG、JPEG、BMP、WEBP格式；
+图片分辨率：长边分辨率范围【192，4096】；
+图片大小：不超过10M；
+图片宽高比：【宽：高】数值在 1:2 到 1:1.2 范围内
+        :rtype: str
+        """
+        return self._ImageUrl
+
+    @ImageUrl.setter
+    def ImageUrl(self, ImageUrl):
+        self._ImageUrl = ImageUrl
+
+    @property
+    def ImageBase64(self):
+        """图片base64数据。
+图片格式：支持PNG、JPG、JPEG、BMP、WEBP格式；
+图片分辨率：长边分辨率范围【192，4096】；
+图片大小：不超过10M；
+图片宽高比：【宽：高】数值在 1:2 到 1:1.2 范围内
+        :rtype: str
+        """
+        return self._ImageBase64
+
+    @ImageBase64.setter
+    def ImageBase64(self, ImageBase64):
+        self._ImageBase64 = ImageBase64
+
+    @property
+    def EnableBodyJoins(self):
+        """是否检测输入图人体12个身体部位（头部、颈部、右肩、右肘、右腕、左肩、左肘、左腕、右髋、左髋,、左膝、右膝）。默认不检测。
+        :rtype: bool
+        """
+        return self._EnableBodyJoins
+
+    @EnableBodyJoins.setter
+    def EnableBodyJoins(self, EnableBodyJoins):
+        self._EnableBodyJoins = EnableBodyJoins
+
+
+    def _deserialize(self, params):
+        self._TemplateId = params.get("TemplateId")
+        self._ImageUrl = params.get("ImageUrl")
+        self._ImageBase64 = params.get("ImageBase64")
+        self._EnableBodyJoins = params.get("EnableBodyJoins")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            property_name = name[1:]
+            if property_name in memeber_set:
+                memeber_set.remove(property_name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class CheckAnimateImageJobResponse(AbstractModel):
+    """CheckAnimateImageJob返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _CheckPass: 输入图是否通过校验。
+        :type CheckPass: bool
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self._CheckPass = None
+        self._RequestId = None
+
+    @property
+    def CheckPass(self):
+        """输入图是否通过校验。
+        :rtype: bool
+        """
+        return self._CheckPass
+
+    @CheckPass.setter
+    def CheckPass(self, CheckPass):
+        self._CheckPass = CheckPass
+
+    @property
+    def RequestId(self):
+        """唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :rtype: str
+        """
+        return self._RequestId
+
+    @RequestId.setter
+    def RequestId(self, RequestId):
+        self._RequestId = RequestId
+
+
+    def _deserialize(self, params):
+        self._CheckPass = params.get("CheckPass")
+        self._RequestId = params.get("RequestId")
+
+
 class ConfirmVideoTranslateJobRequest(AbstractModel):
     """ConfirmVideoTranslateJob请求参数结构体
 
@@ -97,7 +235,7 @@ class ConfirmVideoTranslateJobRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _JobId: 视频翻译任务 ID
+        :param _JobId: 视频转译任务 ID
         :type JobId: str
         :param _TranslateResults: 待确认文本
         :type TranslateResults: list of TranslateResult
@@ -107,7 +245,7 @@ class ConfirmVideoTranslateJobRequest(AbstractModel):
 
     @property
     def JobId(self):
-        """视频翻译任务 ID
+        """视频转译任务 ID
         :rtype: str
         """
         return self._JobId
@@ -153,15 +291,15 @@ class ConfirmVideoTranslateJobResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _JobId: 视频翻译任务 ID
+        :param _JobId: 视频转译任务 ID。
         :type JobId: str
-        :param _TaskId: 音频转换任务 ID
+        :param _TaskId: 音频转译任务 ID。
         :type TaskId: str
-        :param _SessionId: 音频翻译结果确认 session	
+        :param _SessionId: 音频转译结果确认 session。	
         :type SessionId: str
-        :param _Status: 视频转译任务状态	
+        :param _Status: 该字段与 DescribeVideoTranslateJob 接口的 Status 功能相同，均表示任务状态。0：任务初始化。1：音频翻译中。 2：音频翻译失败。 3：音频翻译成功。 4：音频结果待确认。 5：音频结果已确认完毕。6：视频翻译中。 7：视频翻译失败。 8：视频翻译成功。
         :type Status: int
-        :param _Message: 视频转译任务信息	
+        :param _Message: 视频转译任务信息。	
         :type Message: str
         :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
@@ -175,7 +313,7 @@ class ConfirmVideoTranslateJobResponse(AbstractModel):
 
     @property
     def JobId(self):
-        """视频翻译任务 ID
+        """视频转译任务 ID。
         :rtype: str
         """
         return self._JobId
@@ -186,7 +324,7 @@ class ConfirmVideoTranslateJobResponse(AbstractModel):
 
     @property
     def TaskId(self):
-        """音频转换任务 ID
+        """音频转译任务 ID。
         :rtype: str
         """
         return self._TaskId
@@ -197,7 +335,7 @@ class ConfirmVideoTranslateJobResponse(AbstractModel):
 
     @property
     def SessionId(self):
-        """音频翻译结果确认 session	
+        """音频转译结果确认 session。	
         :rtype: str
         """
         return self._SessionId
@@ -208,7 +346,7 @@ class ConfirmVideoTranslateJobResponse(AbstractModel):
 
     @property
     def Status(self):
-        """视频转译任务状态	
+        """该字段与 DescribeVideoTranslateJob 接口的 Status 功能相同，均表示任务状态。0：任务初始化。1：音频翻译中。 2：音频翻译失败。 3：音频翻译成功。 4：音频结果待确认。 5：音频结果已确认完毕。6：视频翻译中。 7：视频翻译失败。 8：视频翻译成功。
         :rtype: int
         """
         return self._Status
@@ -219,7 +357,7 @@ class ConfirmVideoTranslateJobResponse(AbstractModel):
 
     @property
     def Message(self):
-        """视频转译任务信息	
+        """视频转译任务信息。	
         :rtype: str
         """
         return self._Message
@@ -595,14 +733,19 @@ class DescribeVideoStylizationJobResponse(AbstractModel):
         r"""
         :param _JobId: 任务ID。
         :type JobId: str
-        :param _StatusCode: 任务状态码：
-JobInit:  "初始化中"
-JobModerationFailed: "审核失败",
-JobRunning: "处理中",
-JobFailed: "处理失败",
+        :param _StatusCode: 任务状态码。取值说明：
+JobInit:  "初始化中"；
+JobModerationFailed: "审核失败"；
+JobRunning: "处理中"；
+JobFailed: "处理失败"；
 JobSuccess: "处理完成"。
         :type StatusCode: str
-        :param _StatusMsg: 任务状态描述。
+        :param _StatusMsg: 任务状态描述。取值说明：
+JobInit:  "初始化中"；
+JobModerationFailed: "审核失败"；
+JobRunning: "处理中"；
+JobFailed: "处理失败"；
+JobSuccess: "处理完成"。
         :type StatusMsg: str
         :param _ResultVideoUrl: 处理结果视频Url。URL有效期为24小时。
         :type ResultVideoUrl: str
@@ -628,11 +771,11 @@ JobSuccess: "处理完成"。
 
     @property
     def StatusCode(self):
-        """任务状态码：
-JobInit:  "初始化中"
-JobModerationFailed: "审核失败",
-JobRunning: "处理中",
-JobFailed: "处理失败",
+        """任务状态码。取值说明：
+JobInit:  "初始化中"；
+JobModerationFailed: "审核失败"；
+JobRunning: "处理中"；
+JobFailed: "处理失败"；
 JobSuccess: "处理完成"。
         :rtype: str
         """
@@ -644,7 +787,12 @@ JobSuccess: "处理完成"。
 
     @property
     def StatusMsg(self):
-        """任务状态描述。
+        """任务状态描述。取值说明：
+JobInit:  "初始化中"；
+JobModerationFailed: "审核失败"；
+JobRunning: "处理中"；
+JobFailed: "处理失败"；
+JobSuccess: "处理完成"。
         :rtype: str
         """
         return self._StatusMsg
@@ -727,31 +875,32 @@ class DescribeVideoTranslateJobResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _JobStatus: 任务状态。 1：音频翻译中。 2：音频翻译失败。 3：音频翻译成功。 4：音频结果待确认。 5：音频结果已确认完毕。6：视频翻译中。 7：视频翻译失败。 8：视频翻译成功。	
+        :param _JobStatus: 任务状态。0: 任务初始化。 1：音频转译中。 2：音频转译失败。 3：音频转译成功。 4：音频结果待确认。 5：音频结果已确认完毕。6：视频转译中。 7：视频转译失败。 8：视频转译成功。	
         :type JobStatus: int
-        :param _JobErrorCode: 任务错误码。	
+        :param _JobErrorCode: 本次任务出错的错误码，用来定位问题原因。
         :type JobErrorCode: str
-        :param _JobErrorMsg: 任务错误信息。	
+        :param _JobErrorMsg: 任务错误信息，错误码出现的原因。
         :type JobErrorMsg: str
-        :param _ResultVideoUrl: 视频翻译结果。	
+        :param _ResultVideoUrl: 视频转译生成结果视频url，有效期1天。当JobStatus为8时，该字段返回视频Url。
         :type ResultVideoUrl: str
-        :param _TranslateResults: 音频翻译结果。	
+        :param _TranslateResults: 音频转译后分句翻译内容，包含分句起始时间、源识别文本以及翻译后文本。
+当JobStatus为3、4时，该字段返回分句翻译数据。
         :type TranslateResults: list of TranslateResult
-        :param _JobConfirm: 是否需要确认翻译结果。0：不需要，1：需要	
+        :param _JobConfirm: 是否需要确认翻译结果。0：不需要，1：需要。	
         :type JobConfirm: int
-        :param _JobAudioTaskId: 音频任务 ID	
+        :param _JobAudioTaskId: 音频任务 ID。	
         :type JobAudioTaskId: str
-        :param _JobVideoModerationId: 视频审核任务ID	
+        :param _JobVideoModerationId: 视频审核任务ID。
         :type JobVideoModerationId: str
-        :param _JobAudioModerationId: 音频审核任务 ID	
+        :param _JobAudioModerationId: 音频审核任务 ID。
         :type JobAudioModerationId: str
-        :param _JobVideoId: 口型驱动任务 ID	
+        :param _JobVideoId: 口型驱动任务 ID。
         :type JobVideoId: str
-        :param _OriginalVideoUrl: 视频素材原始 URL	
+        :param _OriginalVideoUrl: 视频素材原始 URL。
         :type OriginalVideoUrl: str
-        :param _AsrTimestamps: 文本片段及其时间戳	
+        :param _AsrTimestamps: 文本片段及其时间戳。
         :type AsrTimestamps: list of AsrTimestamps
-        :param _JobSubmitReqId: 提交视频翻译任务时的 requestId	
+        :param _JobSubmitReqId: 提交视频转译任务时的 requestId。
         :type JobSubmitReqId: str
         :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
@@ -773,7 +922,7 @@ class DescribeVideoTranslateJobResponse(AbstractModel):
 
     @property
     def JobStatus(self):
-        """任务状态。 1：音频翻译中。 2：音频翻译失败。 3：音频翻译成功。 4：音频结果待确认。 5：音频结果已确认完毕。6：视频翻译中。 7：视频翻译失败。 8：视频翻译成功。	
+        """任务状态。0: 任务初始化。 1：音频转译中。 2：音频转译失败。 3：音频转译成功。 4：音频结果待确认。 5：音频结果已确认完毕。6：视频转译中。 7：视频转译失败。 8：视频转译成功。	
         :rtype: int
         """
         return self._JobStatus
@@ -784,7 +933,7 @@ class DescribeVideoTranslateJobResponse(AbstractModel):
 
     @property
     def JobErrorCode(self):
-        """任务错误码。	
+        """本次任务出错的错误码，用来定位问题原因。
         :rtype: str
         """
         return self._JobErrorCode
@@ -795,7 +944,7 @@ class DescribeVideoTranslateJobResponse(AbstractModel):
 
     @property
     def JobErrorMsg(self):
-        """任务错误信息。	
+        """任务错误信息，错误码出现的原因。
         :rtype: str
         """
         return self._JobErrorMsg
@@ -806,7 +955,7 @@ class DescribeVideoTranslateJobResponse(AbstractModel):
 
     @property
     def ResultVideoUrl(self):
-        """视频翻译结果。	
+        """视频转译生成结果视频url，有效期1天。当JobStatus为8时，该字段返回视频Url。
         :rtype: str
         """
         return self._ResultVideoUrl
@@ -817,7 +966,8 @@ class DescribeVideoTranslateJobResponse(AbstractModel):
 
     @property
     def TranslateResults(self):
-        """音频翻译结果。	
+        """音频转译后分句翻译内容，包含分句起始时间、源识别文本以及翻译后文本。
+当JobStatus为3、4时，该字段返回分句翻译数据。
         :rtype: list of TranslateResult
         """
         return self._TranslateResults
@@ -828,7 +978,7 @@ class DescribeVideoTranslateJobResponse(AbstractModel):
 
     @property
     def JobConfirm(self):
-        """是否需要确认翻译结果。0：不需要，1：需要	
+        """是否需要确认翻译结果。0：不需要，1：需要。	
         :rtype: int
         """
         return self._JobConfirm
@@ -839,7 +989,7 @@ class DescribeVideoTranslateJobResponse(AbstractModel):
 
     @property
     def JobAudioTaskId(self):
-        """音频任务 ID	
+        """音频任务 ID。	
         :rtype: str
         """
         return self._JobAudioTaskId
@@ -850,7 +1000,7 @@ class DescribeVideoTranslateJobResponse(AbstractModel):
 
     @property
     def JobVideoModerationId(self):
-        """视频审核任务ID	
+        """视频审核任务ID。
         :rtype: str
         """
         return self._JobVideoModerationId
@@ -861,7 +1011,7 @@ class DescribeVideoTranslateJobResponse(AbstractModel):
 
     @property
     def JobAudioModerationId(self):
-        """音频审核任务 ID	
+        """音频审核任务 ID。
         :rtype: str
         """
         return self._JobAudioModerationId
@@ -872,7 +1022,7 @@ class DescribeVideoTranslateJobResponse(AbstractModel):
 
     @property
     def JobVideoId(self):
-        """口型驱动任务 ID	
+        """口型驱动任务 ID。
         :rtype: str
         """
         return self._JobVideoId
@@ -883,7 +1033,7 @@ class DescribeVideoTranslateJobResponse(AbstractModel):
 
     @property
     def OriginalVideoUrl(self):
-        """视频素材原始 URL	
+        """视频素材原始 URL。
         :rtype: str
         """
         return self._OriginalVideoUrl
@@ -894,7 +1044,7 @@ class DescribeVideoTranslateJobResponse(AbstractModel):
 
     @property
     def AsrTimestamps(self):
-        """文本片段及其时间戳	
+        """文本片段及其时间戳。
         :rtype: list of AsrTimestamps
         """
         return self._AsrTimestamps
@@ -905,7 +1055,7 @@ class DescribeVideoTranslateJobResponse(AbstractModel):
 
     @property
     def JobSubmitReqId(self):
-        """提交视频翻译任务时的 requestId	
+        """提交视频转译任务时的 requestId。
         :rtype: str
         """
         return self._JobSubmitReqId
@@ -1109,12 +1259,16 @@ class SubmitImageAnimateJobRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _ImageUrl: 图片格式：支持PNG、JPG、JPEG格式；
-图片分辨率：长边分辨率不超过2056；
+        :param _ImageUrl: 图片格式：支持PNG、JPG、JPEG、BMP、WEBP格式；
+图片分辨率：长边分辨率范围【192，4096】；
 图片大小：不超过10M；
 图片宽高比：【宽：高】数值在 1:2 到 1:1.2 范围内
         :type ImageUrl: str
-        :param _ImageBase64: 图片base64数据。图片格式：支持PNG、JPG、JPEG格式；图片分辨率：长边分辨率不超过2056；图片大小：不超过10M；图片宽高比：【宽：高】数值在 1:2 到 1:1.2 范围内
+        :param _ImageBase64: 图片base64数据。
+图片格式：支持PNG、JPG、JPEG、BMP、WEBP格式；
+图片分辨率：长边分辨率范围【192，4096】；
+图片大小：不超过10M；
+图片宽高比：【宽：高】数值在 1:2 到 1:1.2 范围内
         :type ImageBase64: str
         :param _TemplateId: 动作模板ID。取值说明：ke3 科目三；tuziwu 兔子舞；huajiangwu 划桨舞。
 
@@ -1123,7 +1277,7 @@ class SubmitImageAnimateJobRequest(AbstractModel):
         :type EnableAudio: bool
         :param _EnableBodyJoins: 是否检测输入图人体12个身体部位（头部、颈部、右肩、右肘、右腕、左肩、左肘、左腕、右髋、左髋,、左膝、右膝）。默认不检测。
         :type EnableBodyJoins: bool
-        :param _EnableSegment: 最终视频是否保留原图的背景（该模式对于tuziwu、huajiangwu不生效）
+        :param _EnableSegment: 最终视频是否保留原图的背景，默认不保留。
 
         :type EnableSegment: bool
         :param _LogoAdd: 为生成视频添加标识的开关，默认为0。
@@ -1147,8 +1301,8 @@ class SubmitImageAnimateJobRequest(AbstractModel):
 
     @property
     def ImageUrl(self):
-        """图片格式：支持PNG、JPG、JPEG格式；
-图片分辨率：长边分辨率不超过2056；
+        """图片格式：支持PNG、JPG、JPEG、BMP、WEBP格式；
+图片分辨率：长边分辨率范围【192，4096】；
 图片大小：不超过10M；
 图片宽高比：【宽：高】数值在 1:2 到 1:1.2 范围内
         :rtype: str
@@ -1161,7 +1315,11 @@ class SubmitImageAnimateJobRequest(AbstractModel):
 
     @property
     def ImageBase64(self):
-        """图片base64数据。图片格式：支持PNG、JPG、JPEG格式；图片分辨率：长边分辨率不超过2056；图片大小：不超过10M；图片宽高比：【宽：高】数值在 1:2 到 1:1.2 范围内
+        """图片base64数据。
+图片格式：支持PNG、JPG、JPEG、BMP、WEBP格式；
+图片分辨率：长边分辨率范围【192，4096】；
+图片大小：不超过10M；
+图片宽高比：【宽：高】数值在 1:2 到 1:1.2 范围内
         :rtype: str
         """
         return self._ImageBase64
@@ -1206,7 +1364,7 @@ class SubmitImageAnimateJobRequest(AbstractModel):
 
     @property
     def EnableSegment(self):
-        """最终视频是否保留原图的背景（该模式对于tuziwu、huajiangwu不生效）
+        """最终视频是否保留原图的背景，默认不保留。
 
         :rtype: bool
         """
@@ -1272,7 +1430,7 @@ class SubmitImageAnimateJobResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _JobId: 任务ID。
+        :param _JobId: 图片跳舞任务ID。
         :type JobId: str
         :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
@@ -1282,7 +1440,7 @@ class SubmitImageAnimateJobResponse(AbstractModel):
 
     @property
     def JobId(self):
-        """任务ID。
+        """图片跳舞任务ID。
         :rtype: str
         """
         return self._JobId
@@ -1522,7 +1680,11 @@ class SubmitVideoStylizationJobRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _StyleId: 风格ID，取值说明：2d_anime 2D动漫；3d_cartoon 3D卡通；3d_china 3D国潮；pixel_art	像素风。
+        :param _StyleId: 风格ID。取值说明：
+2d_anime：2D动漫；
+3d_cartoon：3D卡通；
+3d_china：3D国潮；
+pixel_art：像素风。
         :type StyleId: str
         :param _VideoUrl: 输入视频URL。视频要求：
 - 视频格式：mp4、mov；
@@ -1531,9 +1693,11 @@ class SubmitVideoStylizationJobRequest(AbstractModel):
 - 视频大小：不超过200M；
 - 视频FPS：15～60fps。
         :type VideoUrl: str
-        :param _StyleStrength: 风格化强度 可选参数["low","medium","high"] 
-"low":风格化强度弱,"medium":"风格化强度中等","high":"风格化强度强" 
-默认为medium
+        :param _StyleStrength: 风格化强度。取值说明：
+low：风格化强度弱；
+medium：风格化强度中等；
+high：风格化强度强。
+默认值为medium。
         :type StyleStrength: str
         """
         self._StyleId = None
@@ -1542,7 +1706,11 @@ class SubmitVideoStylizationJobRequest(AbstractModel):
 
     @property
     def StyleId(self):
-        """风格ID，取值说明：2d_anime 2D动漫；3d_cartoon 3D卡通；3d_china 3D国潮；pixel_art	像素风。
+        """风格ID。取值说明：
+2d_anime：2D动漫；
+3d_cartoon：3D卡通；
+3d_china：3D国潮；
+pixel_art：像素风。
         :rtype: str
         """
         return self._StyleId
@@ -1569,9 +1737,11 @@ class SubmitVideoStylizationJobRequest(AbstractModel):
 
     @property
     def StyleStrength(self):
-        """风格化强度 可选参数["low","medium","high"] 
-"low":风格化强度弱,"medium":"风格化强度中等","high":"风格化强度强" 
-默认为medium
+        """风格化强度。取值说明：
+low：风格化强度弱；
+medium：风格化强度中等；
+high：风格化强度强。
+默认值为medium。
         :rtype: str
         """
         return self._StyleStrength
@@ -1602,7 +1772,7 @@ class SubmitVideoStylizationJobResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _JobId: 任务ID
+        :param _JobId: 任务ID。任务有效期为48小时。
         :type JobId: str
         :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
@@ -1612,7 +1782,7 @@ class SubmitVideoStylizationJobResponse(AbstractModel):
 
     @property
     def JobId(self):
-        """任务ID
+        """任务ID。任务有效期为48小时。
         :rtype: str
         """
         return self._JobId
@@ -1657,7 +1827,7 @@ fps 要求：【15-60】fps
 目前支持语种范围：zh(中文), en(英文)
         :type SrcLang: str
         :param _AudioUrl: 当音频 URL 不为空时，不经过语音AI处理，直接以视频为素材用音频内容做视频口型驱动。
-格式要求：支持 mp3、m4a、acc、wav 格式。
+格式要求：支持 mp3、m4a、aac、wav 格式。
 时长要求：【5~600】秒，音频时长要匹配视频时长。
 大小要求：不超过 100Mb。
         :type AudioUrl: str
@@ -1723,7 +1893,7 @@ fps 要求：【15-60】fps
     @property
     def AudioUrl(self):
         """当音频 URL 不为空时，不经过语音AI处理，直接以视频为素材用音频内容做视频口型驱动。
-格式要求：支持 mp3、m4a、acc、wav 格式。
+格式要求：支持 mp3、m4a、aac、wav 格式。
 时长要求：【5~600】秒，音频时长要匹配视频时长。
 大小要求：不超过 100Mb。
         :rtype: str
